@@ -181,6 +181,7 @@ usage(FILE *out, const char *name)
           " -C, --no-cursor       ignore cursor events.\n"
           " -T, --no-touch        ignore touch events.\n"
           " -K, --no-keyboard     ignore keyboard events.\n"
+          " --binding             use alternative key bindings. Available options: vim\n"
           " --scrollbar           display scrollbar. (none (default), always, autohide)\n"
           " --accept-single       immediately return if there is only one item.\n"
           " --ifne                only display menu if there are items.\n"
@@ -308,6 +309,7 @@ do_getopt(struct client *client, int *argc, char **argv[])
         { "scb",          required_argument, 0, 0x114 },
         { "scf",          required_argument, 0, 0x115 },
         { "bdr",          required_argument, 0, 0x121 },
+        { "binding",      required_argument, 0, 0x128 },
 
         { "disco",       no_argument,       0, 0x116 },
         { 0, 0, 0, 0 }
@@ -320,7 +322,7 @@ do_getopt(struct client *client, int *argc, char **argv[])
     for (optind = 0;;) {
         int32_t opt;
 
-        if ((opt = getopt_long(*argc, *argv, "hviwxcl:I:p:P:I:bfm:H:M:W:B:nsCTK", opts, NULL)) < 0)
+        if ((opt = getopt_long(*argc, *argv, "hviwxcl:I:p:P:I:bfF:m:H:M:W:B:nsCTK", opts, NULL)) < 0)
             break;
 
         switch (opt) {
@@ -479,6 +481,13 @@ do_getopt(struct client *client, int *argc, char **argv[])
             case 0x121:
                 client->colors[BM_COLOR_BORDER] = optarg;
                 break;
+            case 0x128:
+                if(strcmp(optarg, "vim") == 0){
+                    client->key_binding = BM_KEY_BINDING_VIM;
+                } else {
+                    client->key_binding = BM_KEY_BINDING_DEFAULT;
+                }
+                break;
 
             case 0x116:
                 disco();
@@ -534,6 +543,7 @@ menu_with_options(struct client *client)
     bm_menu_set_password(menu, client->password);
     bm_menu_set_width(menu, client->hmargin_size, client->width_factor);
     bm_menu_set_border_size(menu, client->border_size);
+    bm_menu_set_key_binding(menu, client->key_binding);
 
     if (client->center) {
         bm_menu_set_align(menu, BM_ALIGN_CENTER);
@@ -559,6 +569,10 @@ menu_with_options(struct client *client)
 enum bm_run_result
 run_menu(const struct client *client, struct bm_menu *menu, void (*item_cb)(const struct client *client, struct bm_item *item))
 {
+    bm_menu_set_highlighted_index(menu, client->selected);
+    bm_menu_grab_keyboard(menu, true);
+    bm_menu_set_filter(menu, client->initial_filter);
+
     {
     uint32_t total_item_count;
     struct bm_item **items = bm_menu_get_items(menu, &total_item_count);
@@ -574,10 +588,6 @@ run_menu(const struct client *client, struct bm_menu *menu, void (*item_cb)(cons
 
     }
 
-    bm_menu_set_highlighted_index(menu, client->selected);
-    bm_menu_grab_keyboard(menu, true);
-    bm_menu_set_filter(menu, client->initial_filter);
-
     uint32_t unicode;
     enum bm_key key = BM_KEY_NONE;
     struct bm_pointer pointer;
